env_restore: Restore Saved Environment

View source: R/env.R

env_restoreR Documentation

Restore Saved Environment

Description

Restore Saved Environment

Usage

env_restore(
  from = ".envirs/",
  file = get_latest_file(from),
  rm_all = TRUE,
  envir = .GlobalEnv
)

Arguments

from

Character, directory where environment data is stored. Defaults to .envirs/

file

Character, which file in from contains the environment you wish to restore. Defaults to the most recently modified

rm_all

Logical, whether or not to remove current environment data before loading data from new environment. Defaults to TRUE

envir

Environment, where data will be loaded. Defaults to .GlobalEnv

Value

Loads all variables to envir


EricLamphere/ezextras documentation built on Sept. 14, 2022, 3:09 p.m.