env_save: Snapshot of Global Environment

View source: R/env.R

env_saveR Documentation

Snapshot of Global Environment

Description

Snapshot of Global Environment

Usage

env_save(to = ".envirs/", envir = .GlobalEnv)

Arguments

to

Character, file path where the environment data will be saved. Defaults to .envirs/

envir

Environment, which environment you want to save. Defaults to .GlobalEnv

Value

Invisible, location of the file containing saved environment data


EricLamphere/ezextras documentation built on Sept. 14, 2022, 3:09 p.m.