grapes-and-grapes: Concatenate Strings

%&%R Documentation

Concatenate Strings

Description

Concatenate vectors after converting to character and ignoring NAs.

Usage

x %&% y

Arguments

x

First R object to be converted to a character vector and concatenated to the left of y.

y

Second R object to be converted to a character vector and concatenated to the right of x.

Value

Character, concatenated strings x and y, less NAs. See paste documentation for more information.


EricLamphere/ezextras documentation built on Sept. 14, 2022, 3:09 p.m.