grapes-not-twiddle-grapes: Anti-Pattern Matching

%not~%R Documentation

Anti-Pattern Matching

Description

Search for anti-matches to an argument pattern within each element of a character vector. Uses perl style regex and ignores case. See grepl documentation for more information.

Usage

x %not~% reg

Arguments

x

Character vector

reg

Character string containing a regular expression to be anti-matched in the given character vector.

Value

Logical, whether or not x doesn't match reg. See grepl documentation for more information.


EricLamphere/ezextras documentation built on Sept. 14, 2022, 3:09 p.m.