grapes-slash-slash-grapes: Concatenate Strings

%//%R Documentation

Concatenate Strings

Description

Concatenate filepaths

Usage

x %//% y

Arguments

x

Character, first part of a string to be concatenated to the beginning of y

y

Character, second part f a string to be concatenated to the end of x

Value

Character, concatenated strings x and y, with "/" added or removed when necessary


EricLamphere/ezextras documentation built on Sept. 14, 2022, 3:09 p.m.