grapes-twiddle-grapes: Pattern Matching

%~%R Documentation

Pattern Matching

Description

Search for matches to an argument pattern within each element of a character vector. Uses perl style regex and ignores case. See grepl documentation for more information.

Usage

x %~% reg

Arguments

x

Character vector

reg

Character string containing a regular expression to be matched in the given character vector.

Value

Logical, whether or not x matches reg. See grepl documentation for more information.


EricLamphere/ezextras documentation built on Sept. 14, 2022, 3:09 p.m.