see: Wrapper for 'View' - Invoke Data Viewer

View source: R/see.R

seeR Documentation

Wrapper for View - Invoke Data Viewer

Description

see(x) = View(x). See View documentation with ?View for more information.

Usage

see(x)

Arguments

x

an R object which can be coerced to a data frame with non-zero numbers of rows and columns.

Value

Invisible NULL. The functions puts up a window and returns immediately: the window can be closed via its controls or menus.


EricLamphere/ezextras documentation built on Sept. 14, 2022, 3:09 p.m.