| env_save | R Documentation |
Snapshot of Global Environment
env_save(to = ".envirs/", envir = .GlobalEnv)
to |
Character, file path where the environment data will be saved. Defaults to |
envir |
Environment, which environment you want to save. Defaults to |
Invisible, location of the file containing saved environment data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.