| %//% | R Documentation |
Concatenate filepaths
x %//% y
x |
Character, first part of a string to be concatenated to the
beginning of |
y |
Character, second part f a string to be concatenated to the end of
|
Character, concatenated strings x and y, with "/" added or
removed when necessary
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.