| %~% | R Documentation |
Search for matches to an argument pattern within each element of
a character vector. Uses perl style regex and ignores case. See
grepl documentation for more information.
x %~% reg
x |
Character vector |
reg |
Character string containing a regular expression to be matched in the given character vector. |
Logical, whether or not x matches reg. See grepl
documentation for more information.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.