| see | R Documentation |
View - Invoke Data Viewersee(x) = View(x). See View documentation with
?View for more information.
see(x)
x |
an R object which can be coerced to a data frame with non-zero numbers of rows and columns. |
Invisible NULL. The functions puts up a window and returns immediately: the window can be closed via its controls or menus.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.